@@ -94,7 +94,7 @@ class KSnapshotWidget : public QWidget, public Ui::KSnapshotWidget
 };
 
 KSnapshot::KSnapshot(QWidget *parent,  KSnapshotObject::CaptureMode mode )
-  : KDialog(parent), KSnapshotObject(), modified(true), savedPosition(QPoint(-1, -1))
+  : KDialog(parent), KSnapshotObject(), modified(true), savedPosition(QPoint(-1, -1)), haveXFixes(false)
 {
     // TEMPORARY Make sure "untitled" enters the string freeze for 4.6, 
     // as explained in http://lists.kde.org/?l=kde-graphics-devel&m=128942871430175&w=2
@@ -182,6 +182,8 @@ KSnapshot::KSnapshot(QWidget *parent,  KSnapshotObject::CaptureMode mode )
         if (!XFixesQueryExtension( dpy, &tmp1, &tmp2 )) {
             mainWidget->cbIncludePointer->hide();
             mainWidget->lblIncludePointer->hide();
+        } else {
+            haveXFixes = true;
         }
     }
 #elif !defined(Q_WS_WIN)
